@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate walking basslines
 
-our $VERSION = '0.0402';
+our $VERSION = '0.0403';
 
 use Data::Dumper::Compact qw(ddc);
 use Carp qw(croak);
@@ -159,7 +159,7 @@ sub generate {
     for my $p (@pitches) {
         my $n = Music::Note->new($p, 'midinum');
         my $x = $n->format('isobase');
-        # TODO Why?
+        # Inspect both # & b
         if ($x =~ /#/) {
             $n->en_eq('flat');
         }
@@ -167,9 +167,7 @@ sub generate {
             $n->en_eq('sharp');
         }
         my $y = $n->format('isobase');
-        if (($scale eq 'major' || $scale eq 'ionian' || $scale eq 'minor' || $scale eq 'aeolian')
-            && (
-            ($flavor =~ /[#b]5/ && ($x eq $tones[4] || $y eq $tones[4]))
+        if (($flavor =~ /[#b]5/ && ($x eq $tones[4] || $y eq $tones[4]))
             ||
             ($flavor =~ /7/ && $flavor !~ /[Mm]7/ && ($x eq $tones[6] || $y eq $tones[6]))
             ||
@@ -180,7 +178,6 @@ sub generate {
             ($flavor =~ /dim/ && ($x eq $tones[6] || $y eq $tones[6]))
             ||
             ($flavor =~ /aug/ && ($x eq $tones[6] || $y eq $tones[6]))
-            )
         ) {
             print "\tDROP: $x\n" if $self->verbose;
             next;
@@ -277,7 +274,7 @@ MIDI::Bassline::Walk - Generate walking basslines
 
 =head1 VERSION
 
-version 0.0402
+version 0.0403
 
 =head1 SYNOPSIS
 
@@ -305,7 +302,8 @@ a drop-in bass player.  Import rendered MIDI into a DAW and alter
 notes until they sound suitable.
 
 The "formula" implemented by this module is basically: "Play any notes
-of the chord, modal chord scale, or chord-root scale."
+of the chord, modal chord scale, or chord-root scale (and drop any
+accidental notes replaced by extended jazz chords)."
 
 The chords recognized by this module, are those known to
 L<Music::Chord::Note>.  Please see the source of that module for the
